@@ -27,7 +27,9 @@
 
 namespace atheris {
 
-void SetupTracer(bool enable_opcode_tracing);
+void SetupTracer(int max_print_funcs, bool enable_opcode_tracing);
+
+void TracerStartInput();
 
 }  // namespace atheris
 
